==> kubernetes-model-batch-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/UncountedTerminatedPodsFluent.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UncountedTerminatedPodsFluent<A extends io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToFailed(java.lang.Integer index,java.lang.String item);
  public A setToFailed(java.lang.Integer index,java.lang.String item);
  public A addToFailed(java.lang.String... items);
  public A addAllToFailed(java.util.Collection<java.lang.String> items);
  public A removeFromFailed(java.lang.String... items);
  public A removeAllFromFailed(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getFailed();
  public java.lang.String getFailed(java.lang.Integer index);
  public java.lang.String getFirstFailed();
  public java.lang.String getLastFailed();
  public java.lang.String getMatchingFailed(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingFailed(java.util.function.Predicate<java.lang.String> predicate);
  public A withFailed(java.util.List<java.lang.String> failed);
  public A withFailed(java.lang.String... failed);
  public java.lang.Boolean hasFailed();
  public A addNewFailed(java.lang.String arg0);
  public A addToSucceeded(java.lang.Integer index,java.lang.String item);
  public A setToSucceeded(java.lang.Integer index,java.lang.String item);
  public A addToSucceeded(java.lang.String... items);
  public A addAllToSucceeded(java.util.Collection<java.lang.String> items);
  public A removeFromSucceeded(java.lang.String... items);
  public A removeAllFromSucceeded(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getSucceeded();
  public java.lang.String getSucceeded(java.lang.Integer index);
  public java.lang.String getFirstSucceeded();
  public java.lang.String getLastSucceeded();
  public java.lang.String getMatchingSucceeded(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingSucceeded(java.util.function.Predicate<java.lang.String> predicate);
  public A withSucceeded(java.util.List<java.lang.String> succeeded);
  public A withSucceeded(java.lang.String... succeeded);
  public java.lang.Boolean hasSucceeded();
  public A addNewSucceeded(java.lang.String arg0);
  
}

==> kubernetes-model-batch-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/UncountedTerminatedPodsFluent.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UncountedTerminatedPodsFluent<A extends io.fabric8.kubernetes.api.model.batch.v1.UncountedTerminatedPodsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToFailed(java.lang.Integer index,java.lang.String item);
  public A setToFailed(java.lang.Integer index,java.lang.String item);
  public A addToFailed(java.lang.String... items);
  public A addAllToFailed(java.util.Collection<java.lang.String> items);
  public A removeFromFailed(java.lang.String... items);
  public A removeAllFromFailed(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getFailed();
  public java.lang.String getFailed(java.lang.Integer index);
  public java.lang.String getFirstFailed();
  public java.lang.String getLastFailed();
  public java.lang.String getMatchingFailed(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingFailed(java.util.function.Predicate<java.lang.String> predicate);
  public A withFailed(java.util.List<java.lang.String> failed);
  public A withFailed(java.lang.String... failed);
  public java.lang.Boolean hasFailed();
  public A addNewFailed(java.lang.String arg0);
  public A addToSucceeded(java.lang.Integer index,java.lang.String item);
  public A setToSucceeded(java.lang.Integer index,java.lang.String item);
  public A addToSucceeded(java.lang.String... items);
  public A addAllToSucceeded(java.util.Collection<java.lang.String> items);
  public A removeFromSucceeded(java.lang.String... items);
  public A removeAllFromSucceeded(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getSucceeded();
  public java.lang.String getSucceeded(java.lang.Integer index);
  public java.lang.String getFirstSucceeded();
  public java.lang.String getLastSucceeded();
  public java.lang.String getMatchingSucceeded(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingSucceeded(java.util.function.Predicate<java.lang.String> predicate);
  public A withSucceeded(java.util.List<java.lang.String> succeeded);
  public A withSucceeded(java.lang.String... succeeded);
  public java.lang.Boolean hasSucceeded();
  public A addNewSucceeded(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
